@@ -2,6 +2,8 @@
 # -*- coding: utf-8 -*-
 # Author: Martín Gaitán <gaitan@gmail.com>
 # based on Bruno Renie's work <bruno@renie.fr>
+# 
+# Contributors: timtam, 
 
 
 """
@@ -20,6 +22,7 @@ from docutils import frontend, nodes, utils, languages
 from docutils.writers import html4css1
 from docutils.parsers.rst import directives
 from docutils._compat import b
+import inspect
 
 
 from . import __version__, url
@@ -61,7 +64,11 @@ class HTML5Translator(html4css1.HTMLTranslator):
         nodes.NodeVisitor.__init__(self, document)
         self.settings = settings = document.settings
         lcode = settings.language_code
-        self.language = languages.get_language(lcode)
+        arglen=len(inspect.getargspec(languages.get_language)[0])
+        if arglen == 2:
+            self.language = languages.get_language(lcode,self.document.reporter)
+        else:
+            self.language = languages.get_language(lcode)
         self.meta = [self.content_type % settings.output_encoding,
                      self.generator % __version__]
         self.head_prefix = []
